﻿Imports System.Threading.Tasks
Imports Windows.Phone.Speech.Recognition

Partial Public Class CustomGrammar
    Inherits PhoneApplicationPage

    Private recognizerUI As speechrecognizerUI

    Public Sub New()
        InitializeComponent()
    End Sub

    Private Async Sub CustomGrammar_Loaded(sender As Object, e As RoutedEventArgs) Handles Me.Loaded
        Await InitializeSpeechRecognizer()
    End Sub

    Private Async Sub RecognitionButton_Click(sender As Object, e As EventArgs)
        Dim result = Await recognizerUI.RecognizeWithUIAsync()
        If result.ResultStatus = SpeechRecognitionUIStatus.Succeeded Then

            Dim speechConfidence = SpeechRecognitionConfidence.Low
            If optConfidenceHigh.IsChecked Then
                speechConfidence = SpeechRecognitionConfidence.High
            ElseIf optConfidenceMedium.IsChecked Then
                speechConfidence = SpeechRecognitionConfidence.Medium
            End If

            If result.RecognitionResult.TextConfidence >= speechConfidence Then
                Dim genre = result.RecognitionResult.Semantics.Item("Genre")
                Dim category = result.RecognitionResult.Semantics.Item("Category")
                Me.txtRecognized.Text = String.Format("{0}{4}RULE={1}{4}Genre={2}{4}Category={3}",
                                                      result.RecognitionResult.Text, result.RecognitionResult.RuleName,
                                                      genre.Value, category.Value, vbCrLf)
            Else
                Me.txtRecognized.Text = ""
                MessageBox.Show("Non ho capito!!!")
            End If

        End If

    End Sub

    Private Async Function InitializeSpeechRecognizer() As task
        ' Istanzio l'oggetto da utilizzare per il riconoscimento
        recognizerUI = New SpeechRecognizerUI

        ' Imposto alcune proprietà di interfaccia
        recognizerUI.Settings.ListenText = "Dimmi quali album o artisti vuoi trovare"
        recognizerUI.Settings.ExampleText = "Trova artisti nella categoria rock"

        ' Creo l'URI relativo al file di grammatica
        Dim grammarFileUri = New Uri("ms-appx:///SRGSGrammar.xml")

        ' Imposto il file di grammatica ed eseguo il preloading
        recognizerUI.Recognizer.Grammars.AddGrammarFromUri("myGrammar", grammarFileUri)
        Await recognizerUI.Recognizer.PreloadGrammarsAsync()
    End Function


    Private Sub CustomGrammar_Unloaded(sender As Object, e As RoutedEventArgs) Handles Me.Unloaded
        recognizerUI.Dispose()
    End Sub
End Class
